|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r74351 - in sandbox/stopwatches/boost/chrono/stopwatches: . detail
From: vicente.botet_at_[hidden]
Date: 2011-09-11 13:36:08
Author: viboes
Date: 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
New Revision: 74351
URL: http://svn.boost.org/trac/boost/changeset/74351
Log:
Stopwatches: prepare extraction of reporting
Text files modified:
sandbox/stopwatches/boost/chrono/stopwatches/detail/adaptive_string.hpp | 2
sandbox/stopwatches/boost/chrono/stopwatches/detail/default_out.hpp | 2
sandbox/stopwatches/boost/chrono/stopwatches/detail/static_assert.hpp | 2
sandbox/stopwatches/boost/chrono/stopwatches/lightweight_stopwatch.hpp | 142 +++++++++++++++------------------------
sandbox/stopwatches/boost/chrono/stopwatches/scoped_stopclock.hpp | 1
sandbox/stopwatches/boost/chrono/stopwatches/stopwatch.hpp | 24 +++++-
sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_accumulator.hpp | 29 +++++++-
sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_accumulator_time_formatter.hpp | 24 +++---
sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_reporter.hpp | 6
sandbox/stopwatches/boost/chrono/stopwatches/stopwatches.hpp | 16 ++--
10 files changed, 126 insertions(+), 122 deletions(-)
Modified: sandbox/stopwatches/boost/chrono/stopwatches/detail/adaptive_string.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/detail/adaptive_string.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/detail/adaptive_string.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -1,4 +1,4 @@
-// boost/chrono/stopwatch_formatter.hpp ------------------------------------------------------------//
+// boost/chrono/stopwatches/adaptive_string.hpp ------------------------------------------------------------//
// Copyright 2009-2011 Vicente J. Botet Escriba
// Distributed under the Boost Software License, Version 1.0. (See accompanying
// file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
Modified: sandbox/stopwatches/boost/chrono/stopwatches/detail/default_out.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/detail/default_out.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/detail/default_out.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -1,4 +1,4 @@
-// boost/chrono/stopwatch_formatter.hpp ------------------------------------------------------------//
+// boost/chrono/stopwatches/default_out.hpp ------------------------------------------------------------//
// Copyright 2009-2011 Vicente J. Botet Escriba
// Distributed under the Boost Software License, Version 1.0. (See accompanying
// file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
Modified: sandbox/stopwatches/boost/chrono/stopwatches/detail/static_assert.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/detail/static_assert.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/detail/static_assert.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -1,4 +1,4 @@
-// boost/stopwatches/detail/static_assert.hpp --------------------------------------------------------------//
+// boost/chrono/stopwatches/detail/static_assert.hpp --------------------------------------------------------------//
// Copyright 2009-2011 Vicente J. Botet Escriba
// Distributed under the Boost Software License, Version 1.0.
// See http://www.boost.org/LICENSE_1_0.txt
Modified: sandbox/stopwatches/boost/chrono/stopwatches/lightweight_stopwatch.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/lightweight_stopwatch.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/lightweight_stopwatch.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -12,54 +12,20 @@
#include <boost/chrono/chrono.hpp>
#include <boost/chrono/stopwatches/stopwatch_scoped.hpp>
#include <boost/system/error_code.hpp>
-#include <boost/accumulators/framework/accumulator_set.hpp>
-#include <boost/accumulators/statistics/count.hpp>
-#include <boost/accumulators/statistics/sum.hpp>
-#include <boost/accumulators/statistics/min.hpp>
-#include <boost/accumulators/statistics/max.hpp>
-#include <boost/accumulators/statistics/mean.hpp>
+//#include <boost/chrono/chrono_io.hpp>
namespace boost
{
namespace chrono
{
- template <typename Features, typename Weight=void>
- struct lightweight_stopwatch_accumulator_set_traits {
- template <typename D>
- struct apply {
- struct type {
- typedef accumulators::accumulator_set<typename D::rep, Features, Weight> storage_type;
- typedef D duration_type;
- static duration_type get_duration(storage_type& acc_) { return duration_type(accumulators::sum(acc_)); }
- static void set_duration(storage_type& acc_, duration_type d) { acc_(d.count()); }
- static void reset(storage_type& acc_) { acc_=storage_type(); }
- };
- };
- };
-
- struct lightweight_stopwatch_identity_traits {
- template <typename D>
- struct apply {
- struct type {
- typedef D duration_type;
- typedef duration_type storage_type;
- static duration_type get_duration(storage_type& acc_) { return acc_; }
- static void set_duration(storage_type& acc_, duration_type d) { acc_=d; }
- static void reset(storage_type& acc_) { acc_=storage_type(); }
- };
- };
-
- };
-
-
struct dont_start_t{};
static const dont_start_t dont_start = {};
// forward declaration
template <
- typename Clock=chrono::high_resolution_clock,
- typename Traits=lightweight_stopwatch_identity_traits
+ typename Clock,
+ typename Traits
>
class lightweight_stopwatch;
@@ -82,6 +48,7 @@
start_(duration::zero()), level_(0), partial_(duration::zero()), suspend_level_(0)
, storage_(&acc), construction_(clock::now( ))
{
+ //std::cout << "construction_:" << construction_ << std::endl;
start(ec);
}
@@ -90,6 +57,7 @@
start_(duration::zero()), level_(0), partial_(duration::zero()), suspend_level_(0)
, storage_(&acc), construction_(clock::now( ))
{
+ //std::cout << "construction_:" << construction_ << std::endl;
}
~lightweight_stopwatch() {
@@ -101,30 +69,30 @@
//--------------------------------------------------------------------------------------//
std::pair<duration, time_point> restart( system::error_code & ec = BOOST_CHRONO_THROWS )
{
- time_point tmp=clock::now( ec );
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ time_point tmp=clock::now( ec );
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
if (ec) return time_point();
- }
- if (running_&&(level_==1)) {
+ }
+ if (running_&&(level_==1)) {
partial_ += tmp - start_;
traits::set_duration(get_storage(),partial_);
partial_=duration::zero();
- } else {
+ } else {
running_=true;
- }
- start_=tmp;
- return std::make_pair(traits::get_duration(get_storage()),start_);
+ }
+ start_=tmp;
+ return std::make_pair(traits::get_duration(get_storage()),start_);
}
time_point start( system::error_code & ec = BOOST_CHRONO_THROWS )
{
if (!running_) {
time_point tmp = clock::now( ec );
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) {
- return time_point();
- }
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) {
+ return time_point();
+ }
+ }
start_ = tmp;
++level_;
running_ = true;
@@ -140,9 +108,9 @@
{
if (running_ && (--level_==0)) {
time_point tmp=clock::now( ec );
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return duration::zero();
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return duration::zero();
+ }
partial_ += tmp - start_;
traits::set_duration(get_storage(),partial_);
partial_=duration::zero();
@@ -159,9 +127,9 @@
if (running_) {
if (!suspended_) {
time_point tmp=clock::now( ec );
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return duration::zero();
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return duration::zero();
+ }
++suspend_level_;
partial_ += tmp - start_;
suspended_=true;
@@ -181,9 +149,9 @@
{
if (suspended_&&(--suspend_level_==0)) {
time_point tmp = clock::now( ec );
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return time_point();
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return time_point();
+ }
start_ = tmp;
suspended_=false;
return start_;
@@ -200,9 +168,9 @@
return traits::get_duration(get_storage());
else {
time_point tmp = clock::now( ec );
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return duration::zero();
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return duration::zero();
+ }
return traits::get_duration(get_storage())+tmp - start_;
}
} else {
@@ -218,9 +186,9 @@
void reset( system::error_code & ec = BOOST_CHRONO_THROWS )
{
construction_=clock::now( ec );
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return;
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return;
+ }
traits::reset(get_storage());
running_=false;
suspended_=false;
@@ -237,6 +205,8 @@
duration lifetime( system::error_code & ec = BOOST_CHRONO_THROWS )
{
+ //std::cout << "construction_:" << construction_ << std::endl;
+ //std::cout << "now:" << clock::now( ec ) << std::endl;
return clock::now( ec ) - construction_;
}
@@ -256,27 +226,27 @@
};
//--------------------------------------------------------------------------------------//
- typedef accumulators::features<
- accumulators::tag::count,
- accumulators::tag::sum,
- accumulators::tag::min,
- accumulators::tag::max,
- accumulators::tag::mean
- > default_features;
- typedef boost::chrono::lightweight_stopwatch< boost::chrono::system_clock > system_lightweight_stopwatch;
-#ifdef BOOST_CHRONO_HAS_CLOCK_STEADY
- typedef boost::chrono::lightweight_stopwatch< boost::chrono::steady_clock > steady_lightweight_stopwatch;
-#endif
- typedef boost::chrono::lightweight_stopwatch< boost::chrono::high_resolution_clock > high_resolution_lightweight_stopwatch;
-
- typedef boost::chrono::lightweight_stopwatch< boost::chrono::system_clock,
- lightweight_stopwatch_accumulator_set_traits<default_features> > system_lightweight_stopwatch_accumulator;
-#ifdef BOOST_CHRONO_HAS_CLOCK_STEADY
- typedef boost::chrono::lightweight_stopwatch< boost::chrono::steady_clock,
- lightweight_stopwatch_accumulator_set_traits<default_features> > steady_lightweight_stopwatch_accumulator;
-#endif
- typedef boost::chrono::lightweight_stopwatch< boost::chrono::high_resolution_clock,
- lightweight_stopwatch_accumulator_set_traits<default_features> > high_resolution_lightweight_stopwatch_accumulator;
+// typedef accumulators::features<
+// accumulators::tag::count,
+// accumulators::tag::sum,
+// accumulators::tag::min,
+// accumulators::tag::max,
+// accumulators::tag::mean
+// > default_features;
+// typedef boost::chrono::lightweight_stopwatch< boost::chrono::system_clock > system_lightweight_stopwatch;
+//#ifdef BOOST_CHRONO_HAS_CLOCK_STEADY
+// typedef boost::chrono::lightweight_stopwatch< boost::chrono::steady_clock > steady_lightweight_stopwatch;
+//#endif
+// typedef boost::chrono::lightweight_stopwatch< boost::chrono::high_resolution_clock > high_resolution_lightweight_stopwatch;
+//
+// typedef boost::chrono::lightweight_stopwatch< boost::chrono::system_clock,
+// lightweight_stopwatch_accumulator_set_traits<default_features> > system_lightweight_stopwatch_accumulator;
+//#ifdef BOOST_CHRONO_HAS_CLOCK_STEADY
+// typedef boost::chrono::lightweight_stopwatch< boost::chrono::steady_clock,
+// lightweight_stopwatch_accumulator_set_traits<default_features> > steady_lightweight_stopwatch_accumulator;
+//#endif
+// typedef boost::chrono::lightweight_stopwatch< boost::chrono::high_resolution_clock,
+// lightweight_stopwatch_accumulator_set_traits<default_features> > high_resolution_lightweight_stopwatch_accumulator;
//--------------------------------------------------------------------------------------//
Modified: sandbox/stopwatches/boost/chrono/stopwatches/scoped_stopclock.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/scoped_stopclock.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/scoped_stopclock.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -12,6 +12,7 @@
#include <boost/chrono/process_cpu_clocks.hpp>
#include <boost/chrono/stopwatches/time_formatter.hpp>
#include <boost/chrono/stopwatches/stopwatch_accumulator_time_formatter.hpp>
+#include <boost/chrono/stopwatches/stopclock.hpp>
namespace boost { namespace chrono {
Modified: sandbox/stopwatches/boost/chrono/stopwatches/stopwatch.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/stopwatch.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/stopwatch.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -19,13 +19,27 @@
namespace chrono
{
+ struct lightweight_stopwatch_identity_traits {
+ template <typename D>
+ struct apply {
+ struct type {
+ typedef D duration_type;
+ typedef duration_type storage_type;
+ static duration_type get_duration(storage_type& acc_) { return acc_; }
+ static void set_duration(storage_type& acc_, duration_type d) { acc_=d; }
+ static void reset(storage_type& acc_) { acc_=storage_type(); }
+ };
+ };
+
+ };
+
//--------------------------------------------------------------------------------------//
// stopwatch
//
//~ A stopwatch is a class designed to measure the amount of time elapsed from a particular time
//~ when activated to when it is deactivated.
-//~ Calling start starts the timer running, and calling stop stops it.
+//~ Calling start starts the stopwatch running, and calling stop stops it.
//~ A call to reset resets the stopwatch to zero.
//~ A stopwatch can also also used to record split times or lap times.
//~ The elapsed time since the last start is available through the elapsed function.
@@ -35,22 +49,20 @@
template <class Clock=chrono::system_clock>
class stopwatch;
- //~ struct dont_start_t{};
- //~ static const dont_start_t dont_start = {};
//--------------------------------------------------------------------------------------//
template <class Clock>
- class stopwatch : private base_from_member<typename Clock::duration>, public lightweight_stopwatch<Clock>
+ class stopwatch : private base_from_member<typename Clock::duration>, public lightweight_stopwatch<Clock,lightweight_stopwatch_identity_traits>
{
public:
typedef base_from_member<typename Clock::duration> pbase_type;
explicit stopwatch( system::error_code & ec = BOOST_CHRONO_THROWS )
- : pbase_type(), lightweight_stopwatch<Clock>(pbase_type::member, ec)
+ : pbase_type(), lightweight_stopwatch<Clock,lightweight_stopwatch_identity_traits>(pbase_type::member, ec)
{
}
explicit stopwatch( const dont_start_t& t )
- : pbase_type(), lightweight_stopwatch<Clock>(pbase_type::member, t)
+ : pbase_type(), lightweight_stopwatch<Clock,lightweight_stopwatch_identity_traits>(pbase_type::member, t)
{ }
};
Modified: sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_accumulator.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_accumulator_time_formatter.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_accumulator_time_formatter.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -95,25 +95,25 @@
case 's':
//~ os << boost::chrono::duration<double>(duration_t(accumulators::sum(acc))).count();
time_formatter::show_time<chrono::process_cpu_clock>(accumulators::sum(acc), format2, places, os, ec);
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return;
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return;
+ }
//~ os << accumulators::sum(acc);
break;
case 'm':
//~ os << boost::chrono::duration<double>(duration_t((accumulators::min)(acc))).count();
time_formatter::show_time<chrono::process_cpu_clock>((accumulators::min)(acc), format2, places, os, ec);
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return;
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return;
+ }
//~ os << (accumulators::min)(acc);
break;
case 'M':
//~ os << boost::chrono::duration<double>(duration_t((accumulators::max)(acc))).count();
time_formatter::show_time<chrono::process_cpu_clock>((accumulators::max)(acc), format2, places, os, ec);
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return;
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return;
+ }
//~ os << (accumulators::max)(acc);
break;
case 'a':
@@ -121,9 +121,9 @@
//? os << boost::chrono::duration<double>(duration_t(typename duration_t::rep(accumulators::mean(acc)))).count()
//~ os << boost::chrono::duration<double>(duration_t(accumulators::sum(acc))).count() / accumulators::count(acc)
time_formatter::show_time<chrono::process_cpu_clock>(accumulators::sum(acc) / accumulators::count(acc), format2, places, os, ec);
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return;
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return;
+ }
} else {
os << 0;
}
Modified: sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_reporter.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_reporter.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_reporter.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -175,9 +175,9 @@
template <class Stopwatch, class Formatter>
void basic_stopwatch_reporter<Stopwatch, Formatter>::report( system::error_code & ec ) {
chrono::clock_suspender<typename Stopwatch::clock> _(ec);
- if (!BOOST_CHRONO_IS_THROWS(ec)) {
- if (ec) return;
- }
+ if (!BOOST_CHRONO_IS_THROWS(ec)) {
+ if (ec) return;
+ }
if ( m_format.empty() ) m_format = Formatter::default_format();
m_reported = true;
Modified: sandbox/stopwatches/boost/chrono/stopwatches/stopwatches.hpp
==============================================================================
--- sandbox/stopwatches/boost/chrono/stopwatches/stopwatches.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/stopwatches.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -15,18 +15,18 @@
//-----------------------------------------------------------------------------
#include <boost/chrono/stopwatches/scoped_stopclock.hpp>
-#include <boost/chrono/stopwatches/stopclock.hpp>
-#include <boost/chrono/stopwatches/stopclock_accumulator.hpp>
+//#include <boost/chrono/stopwatches/stopclock.hpp>
+//#include <boost/chrono/stopwatches/stopclock_accumulator.hpp>
#include <boost/chrono/stopwatches/stopwatch.hpp>
#include <boost/chrono/stopwatches/stopwatch_accumulator.hpp>
-#include <boost/chrono/stopwatches/stopwatch_accumulator_formatter.hpp>
-#include <boost/chrono/stopwatches/stopwatch_accumulator_time_formatter.hpp>
-#include <boost/chrono/stopwatches/stopwatch_formatter.hpp>
-#include <boost/chrono/stopwatches/stopwatch_reporter.hpp>
+//#include <boost/chrono/stopwatches/stopwatch_accumulator_formatter.hpp>
+//#include <boost/chrono/stopwatches/stopwatch_accumulator_time_formatter.hpp>
+//#include <boost/chrono/stopwatches/stopwatch_formatter.hpp>
+//#include <boost/chrono/stopwatches/stopwatch_reporter.hpp>
#include <boost/chrono/stopwatches/stopwatch_scoped.hpp>
-#include <boost/chrono/stopwatches/time_formatter.hpp>
+//#include <boost/chrono/stopwatches/time_formatter.hpp>
#include <boost/chrono/stopwatches/t24_hours.hpp>
-#include <boost/chrono/stopwatches/t24_hours_formatter.hpp>
+//#include <boost/chrono/stopwatches/t24_hours_formatter.hpp>
//-----------------------------------------------------------------------------
#endif // BOOST_STOPWATCHES_STOPWATCHES_HPP
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_accumulator.hpp (original)
+++ sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_accumulator.hpp 2011-09-11 13:36:07 EDT (Sun, 11 Sep 2011)
@@ -14,21 +14,41 @@
#include <boost/system/error_code.hpp>
#include <boost/chrono/stopwatches/lightweight_stopwatch.hpp>
#include <boost/utility/base_from_member.hpp>
+#include <boost/accumulators/framework/accumulator_set.hpp>
+#include <boost/accumulators/statistics/count.hpp>
+#include <boost/accumulators/statistics/sum.hpp>
+#include <boost/accumulators/statistics/min.hpp>
+#include <boost/accumulators/statistics/max.hpp>
+#include <boost/accumulators/statistics/mean.hpp>
namespace boost
{
namespace chrono
{
+ template <typename Features, typename Weight=void>
+ struct lightweight_stopwatch_accumulator_set_traits {
+ template <typename D>
+ struct apply {
+ struct type {
+ typedef accumulators::accumulator_set<typename D::rep, Features, Weight> storage_type;
+ typedef D duration_type;
+ static duration_type get_duration(storage_type& acc_) { return duration_type(accumulators::sum(acc_)); }
+ static void set_duration(storage_type& acc_, duration_type d) { acc_(d.count()); }
+ static void reset(storage_type& acc_) { acc_=storage_type(); }
+ };
+ };
+ };
+
//--------------------------------------------------------------------------------------//
-// stopwatch
+// stopwatch_accumulator
//
//~ A stopwatch accumulator is a class designed to measure the amount of time elapsed from a particular time
//~ when activated to when it is deactivated.
//~ Calling start starts the timer running, and calling stop stops it.
//~ A call to reset resets the stopwatch to zero.
//~ A stopwatch can also be used to record split times or lap times.
//~ The elapsed time since the last start is available through the elapsed function.
//--------------------------------------------------------------------------------------//
@@ -57,6 +77,7 @@
{
public:
typedef base_from_member<typename accumulators::accumulator_set<typename Clock::duration::rep, Features, Weight> > pbase_type;
+ typedef typename accumulators::accumulator_set<typename Clock::duration::rep, Features, Weight> accumulator_set;
stopwatch_accumulator( )
: pbase_type(),
Modified: sandbox/stopwatches/boost/chrono/stopwatches/stopwatch_accumulator_time_formatter.hpp
@@ -14,21 +14,41 @@
//~ A stopwatch accumulator is a class designed to measure the amount of time elapsed from a particular time
//~ when activated to when it is deactivated.
-//~ Calling start starts the timer running, and calling stop stops it.
-//~ A call to reset resets the stopwatch to zero.
-//~ A stopwatch can also be used to record split times or lap times.
+//~ Calling start starts the stopwatch_accumulator running, and calling stop stops it.
+//~ A call to reset resets the stopwatch_accumulator to zero.
+//~ A stopwatch_accumulator can also be used to record split times or lap times.
//~ The elapsed time since the last start is available through the elapsed function.
//--------------------------------------------------------------------------------------//
==============================================================================